@@ -1,7 +1,7 @@
 (setf *tries* 2)
 (setf *reminder* 5)
 
-(alert notification "echo '%state% %function% %params% %result%'")
+(alert notification "echo '%state% %function% %params% %result% %date%'")
 
 ;; check for /tmp/ disk usage
 ;; create a big file to increase size
